@@ -22,18 +22,15 @@
 
 #include <QWidget>
 
-namespace Ui
-{
+namespace Ui {
 class ImportMailPage;
 }
 
-namespace Akonadi
-{
+namespace Akonadi {
 class Collection;
 }
 
-namespace MailImporter
-{
+namespace MailImporter {
 class ImportMailsWidget;
 }
 
